@@ -1,10 +1,9 @@
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use utf8;
 
 package Amon2::Setup::Flavor::Basic;
 use parent qw(Amon2::Setup::Flavor::Minimum);
-use HTTP::Status qw/status_message/;
 
 sub run {
     my $self = shift;
@@ -19,6 +18,37 @@ sub run {
     $self->write_asset('jQuery');
     $self->write_asset('Bootstrap');
 
+    $self->write_file('app.psgi', <<'...', {header => $self->psgi_header});
+<% header %>
+use <% $module %>::Web;
+use <% $module %>;
+use Plack::Session::Store::DBI;
+use DBI;
+
+{
+    my $c = <% $module %>->new();
+    $c->setup_schema();
+}
+my $db_config = <% $module %>->config->{DBI} || die "Missing configuration for DBI";
+builder {
+    enable 'Plack::Middleware::Static',
+        path => qr{^(?:/static/)},
+        root => File::Spec->catdir(dirname(__FILE__));
+    enable 'Plack::Middleware::Static',
+        path => qr{^(?:/robots\.txt|/favicon.ico)$},
+        root => File::Spec->catdir(dirname(__FILE__), 'static');
+    enable 'Plack::Middleware::ReverseProxy';
+	enable 'Plack::Middleware::Session',
+        store => Plack::Session::Store::DBI->new(
+            get_dbh => sub {
+                DBI->connect( @$db_config )
+                    or die $DBI::errstr;
+            }
+        );
+    <% $module %>::Web->to_app();
+};
+...
+
     $self->write_file('static/img/.gitignore', '');
 
     $self->write_file('lib/<<PATH>>.pm', <<'...');
@@ -29,7 +59,21 @@ use parent qw/Amon2/;
 our $VERSION='0.01';
 use 5.008001;
 
-# __PACKAGE__->load_plugin(qw/DBI/);
+__PACKAGE__->load_plugin(qw/DBI/);
+
+# initialize database
+use DBI;
+sub setup_schema {
+    my $self = shift;
+    my $dbh = $self->dbh();
+    my $driver_name = $dbh->{Driver}->{Name};
+    my $fname = lc("sql/${driver_name}.sql");
+    open my $fh, '<:encoding(UTF-8)', $fname or die "$fname: $!";
+    my $source = do { local $/; <$fh> };
+	for my $stmt (split /;/, $source) {
+		$dbh->do($stmt) or die $dbh->errstr();
+	}
+}
 
 1;
 ...
@@ -50,22 +94,10 @@ sub dispatch {
 <% $xslate %>
 
 # load plugins
-use File::Path qw(mkpath);
-use HTTP::Session::Store::File;
 __PACKAGE__->load_plugins(
     'Web::FillInFormLite',
     'Web::NoCache', # do not cache the dynamic content by default
     'Web::CSRFDefender',
-    'Web::HTTPSession' => do {
-        my $session_dir = File::Spec->catdir(File::Spec->tmpdir(), '<: $path :>');
-        mkpath($session_dir);
-        +{
-            state => 'Cookie',
-            store => HTTP::Session::Store::File->new(
-                dir => $session_dir,
-            )
-        }
-    },
 );
 
 # for your security
@@ -98,13 +130,33 @@ any '/' => sub {
     $c->render('index.tt');
 };
 
+get '/account/logout' => sub {
+    my ($c) = @_;
+    $c->session->expire();
+    $c->redirect('/');
+};
+
 1;
 ...
 
-    $self->write_file("config/development.pl", <<'...');
+    $self->write_file('db/.gitignore', <<'...');
+*
+...
+
+    for my $env (qw(development deployment test)) {
+        $self->write_file("config/${env}.pl", <<'...', {env => $env});
+use File::Spec;
+use File::Basename qw(dirname);
+my $basedir = File::Spec->rel2abs(File::Spec->catdir(dirname(__FILE__), '..'));
+my $dbpath;
+if ( -d '/home/dotcloud/') {
+    $dbpath = "/home/dotcloud/<% $env %>.db";
+} else {
+    $dbpath = File::Spec->catfile($basedir, 'db', '<% $env %>.db');
+}
 +{
     'DBI' => [
-        'dbi:SQLite:dbname=development.db',
+        "dbi:SQLite:dbname=$dbpath",
         '',
         '',
         +{
@@ -113,36 +165,21 @@ any '/' => sub {
     ],
 };
 ...
+    }
 
-    $self->write_file("config/deployment.pl", <<'...');
-+{
-    'DBI' => [
-        'dbi:SQLite:dbname=deployment.db',
-        '',
-        '',
-        +{
-            sqlite_unicode => 1,
-        }
-    ],
-};
+    $self->write_file("sql/mysql.sql", <<'...');
+CREATE TABLE IF NOT EXISTS sessions (
+    id           CHAR(72) PRIMARY KEY,
+    session_data TEXT
+);
 ...
-
-    $self->write_file("config/test.pl", <<'...');
-+{
-    'DBI' => [
-        'dbi:SQLite:dbname=test.db',
-        '',
-        '',
-        +{
-            sqlite_unicode => 1,
-        }
-    ],
-};
+    $self->write_file("sql/sqlite.sql", <<'...');
+CREATE TABLE IF NOT EXISTS sessions (
+    id           CHAR(72) PRIMARY KEY,
+    session_data TEXT
+);
 ...
 
-    $self->write_file("sql/my.sql", '');
-    $self->write_file("sql/sqlite3.sql", '');
-
     $self->write_file('tmpl/index.tt', <<'...');
 [% WRAPPER 'include/layout.tt' %]
 
@@ -396,6 +433,8 @@ done_testing;
 
     $self->write_file('.proverc', <<'...');
 -l
+-r t
+-Mt::Util
 ...
 
     for my $status (qw/404 500 502 503 504/) {
@@ -406,7 +445,14 @@ done_testing;
 sub write_status_file {
     my ($self, $fname, $status) = @_;
 
-    $self->write_file($fname, <<'...', status => $status, status_message => status_message($status));
+    my $message = {
+        '503' => 'Service Unavailable',
+        '502' => 'Bad Gateway',
+        '500' => 'Internal Server Error',
+        '504' => 'Gateway Timeout',
+        '404' => 'Not Found'
+    }->{$status};
+    $self->write_file($fname, <<'...', status => $status, status_message => $message);
 <!doctype html> 
 <html> 
     <head> 
@@ -436,6 +482,50 @@ sub write_status_file {
 ...
 }
 
+sub create_makefile_pl {
+    my ($self, $prereq_pm) = @_;
+
+    $self->SUPER::create_makefile_pl(
+        +{
+            %{ $prereq_pm || {} },
+            'Plack::Session' => '0.14',
+            'Amon2::DBI'     => '0.05',
+            'DBD::SQLite'    => '1.33',
+        },
+    );
+}
+
+sub create_t_02_mech_t {
+    my ($self, $more) = @_;
+    $more ||= '';
+    $self->SUPER::create_t_02_mech_t(<<'...' . $more);
+$mech->get_ok('/account/logout');
+...
+}
+
+sub create_t_util_pm {
+    my ($self, $export, $more) = @_;
+    $export ||= [];
+    $more ||= '';
+
+	$self->SUPER::create_t_util_pm([@$export, qw(slurp)], $more . "\n" . <<'...');
+sub slurp {
+	my $fname = shift;
+	open my $fh, '<:encoding(UTF-8)', $fname or die "$fname: $!";
+	do { local $/; <$fh> };
+}
+
+# initialize database
+use <% $module %>;
+{
+    unlink 'db/test.db' if -f 'db/test.db';
+
+    my $c = <% $module %>->new();
+    $c->setup_schema();
+}
+...
+}
+
 1;
 __END__
 
